lyricstools.LyricText
=====================

.. inheritance-diagram:: abjad.tools.lyricstools.LyricText.LyricText.LyricText
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.LyricText.LyricText.LyricText

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.duration_in_seconds

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.format

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.leaf_index

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.multiplied_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.preprolated_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.duration_multiplier

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.written_duration

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.written_pitch_indication_is_at_sounding_pitch

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.written_pitch_indication_is_nonsemantic

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__and__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__or__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__repr__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__str__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__sub__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__xor__

   .. note:: Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
